@@ -11,4 +11,7 @@
 utils::globalVariables(c(".data", "obs", "valter","select","ego","zego","alter",
                          "from","to","weight","unit","Step","Freq","Var1","n",
                          "density","wave","period","name","value","sim","time",
-                         "q05","q95"))
+                         "q05","q95","color","group","label","x","y",
+                         "xend","yend","id",
+                         "status","frame","framen",
+                         "S","E","I_new","R"))
